package com.steerinfo.inPlantNavigation.controller;

import com.steerinfo.framework.controller.BaseRESTfulController;
import com.steerinfo.framework.controller.RESTfulResult;

import com.steerinfo.inPlantNavigation.exception.VertexAngEdgeException;
import com.steerinfo.inPlantNavigation.model.IPMMSVertex;
import com.steerinfo.inPlantNavigation.model.IPMMSVertexEdge;
import com.steerinfo.inPlantNavigation.model.MapVertex;
import com.steerinfo.inPlantNavigation.model.MapVertexEdge;
import com.steerinfo.inPlantNavigation.service.IMapVertexEdgeService;
import com.steerinfo.inPlantNavigation.service.IMapVertexService;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.io.IOException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Map;

/**
 * MapVertex RESTful接口：
 * @author generator
 * @version 1.0-SNAPSHORT 2022-04-27 06:36
 * 类描述
 * 修订历史：
 * 日期：2022-04-27
 * 作者：generator
 * 参考：
 * 描述：MapVertex RESTful接口
 * @see null
 * @Copyright 湖南视拓信息技术股份有限公司. All rights reserved.
 */
@RestController
@RequestMapping("/${api.version}/mapvertexs")
public class MapVertexController extends BaseRESTfulController {

    @Autowired
    IMapVertexService mapVertexService;

    @Autowired
    IMapVertexEdgeService mapVertexEdgeService;

    @ApiOperation(value="导入顶点数据，开发用")
    @GetMapping(value = "/importVertex")
    public RESTfulResult importVertex() throws IOException {
        mapVertexService.importVertex("默认文件写死了");
        return success("导入成功");
    }

    @ApiOperation(value="查询所有可用地点")
    @GetMapping(value = "/findAllAvailableVertex")
    public RESTfulResult findAllAvailableVertex(){
        return success(mapVertexService.findAllAvailable());
    }


    @ApiOperation(value="获取最佳路径")
    @GetMapping(value = "/getObtainTheOptimalPath")
    public RESTfulResult getObtainTheOptimalPath(@RequestParam("startPoint") String startPoint,@RequestParam("endPoint")  String endPoint) throws VertexAngEdgeException {
        Map<String, List<MapVertexEdge>> vertexEdgeList= mapVertexEdgeService.initVertexEdge();
        Map<String, MapVertex> vertexList = mapVertexService.initMapVertex();
        ArrayList<MapVertex> obtainTheOptimalPath= mapVertexService.getObtainTheOptimalPath(startPoint,endPoint,vertexEdgeList,vertexList);
        Collections.reverse(obtainTheOptimalPath);
        return success(obtainTheOptimalPath);
    }

    @ApiOperation(value="获取订单路径信息")
    @GetMapping(value = "/findOrderDetails")
    public RESTfulResult findOrderDetails(@RequestParam("orderId") String orderId) throws VertexAngEdgeException {
        return success(mapVertexService.findOrderDetails(orderId));
    }

    @ApiOperation(value="获取当前订单导航路径")
    @GetMapping(value = "/getPathByOrderID")
    public RESTfulResult getPathByOrderID(@RequestParam("orderId") String orderId,@RequestParam("startStep")  String startStep,@RequestParam("endStep")  String endStep) throws VertexAngEdgeException {
        Map<String, List<MapVertexEdge>> vertexEdgeList= mapVertexEdgeService.initVertexEdge();
        Map<String, MapVertex> vertexList = mapVertexService.initMapVertex();
        ArrayList<MapVertex> obtainTheOptimalPath= mapVertexService.getPathByOrderID(orderId,startStep,endStep,vertexList,vertexEdgeList);
        return success(obtainTheOptimalPath);
    }

    @ApiOperation(value="查询所有可选地点")
    @GetMapping(value = "/findSelections")
    public RESTfulResult findSelections(){
        return success(mapVertexService.findSelections());
    }
}
